/*
 * Copyright (C) 2006-2007 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
 */

package com.funambol.syncml.spds;

/**
 * This class groups all configuration properties related to the device.
 * Most of DeviceConfig properties are used to generate the 
 * <pre><DevInf></pre> element for client capabilities.
 * DeviceConfig is a part of SyncConfig.
 *
 */
public class DeviceConfig {

    //--------------------------------------------------------------- Constants
    private static final int MAXMSGSIZE = 16*1024;

    //-------------------------------------------------------------- Attributes
    /**
     * Specifies the major and minor version identifier of the Device
     * Information DTD used in the representation of the Device Information. The
     * value MUST be "1.1". This property is mandatory.
     */
    public String verDTD;

    /**
     * Specifies the name of the manufacturer of the device. Mandatory
     */
    public String man;
    
    /**
     * Specifies the model name or model number of the device. Mandatory
     */
    public String mod;

    /**
     * Specifies the OEM (Original Equipment Manufacturer) of the device. 
     * This property is optional.
     */
    public String oem;

    /**
     * Specifies the firmware version of the device. Mandatory
     */
    public String fwv;

    /**
     * Specifies the software version of the device. Mandatory
     */
    public String swv;

    /**
     * Specifies the hardware version of the device. This property is optional.
     */
    public String hwv;

    /**
     * Specifies the identifier of the source synchronization device. 
     * The content information MUST specify a theoretically, globally unique
     * identifier. This property is mandatory.
     */
    public String devID;

    /**
     * Specifies the type of the source synchronization device. 
     * Type values for this element type can be e.g. "pager", "handheld",
     * "pda", "phone", "smartphone", "server", "workstation". 
     * Other values can also be specified. This property is mandatory.
     */
    public String devType;

    /**
     * Specifies the implemented DS version. This property is optional.           
     */
    public String dsV;

    /**
     * Specifies that the device supports UTC based time. 
     * If utc = TRUE, the server SHOULD send time in UTC format, else MUST
     * send in local time. Default value = TRUE.
     */
    public boolean utc;

    /**
     * Specifies that the device supports handling of large objects. 
     * Default value = FALSE.
     */
    public boolean loSupport;

    /**
     * Specifies that the device supports number of changes. 
     * Default value = FALSE.
     */
    public boolean nocSupport;

    /**
     * Specifies the maximum message size allowed by the device.
     */
    public int maxMsgSize;

    /**
     * Specifies the maximum object size allowed by the device.
     * Default value = 0 (no maxObjSize set).
     */
    public int maxObjSize;

    //------------------------------------------------------------ Constructors

    /**
     * Default constructor. All the mandatory informations are set to 
     * a default value, or to the values actually supported by the current
     * SyncML implementation. The optional fields are set to null.
     *
     * TODO: get the values from the device configuration (e.g. IMEI)
     */
    DeviceConfig() {
        verDTD = "1.1";
        man = null;
        mod = null;
        oem = null;
        fwv = null;
        swv = null;
        hwv = null;
        devID = "fsc-j2me-api";
        devType = "phone";
        dsV = "1.2";
        utc = true;                     // TODO: check this.
        loSupport = false;
        nocSupport = false;
        maxMsgSize = MAXMSGSIZE;
        maxObjSize = MAXMSGSIZE;
    }

}

